/**
 *   CWallpaper-fltk - A frontend for root window pixmap changing programs.
 *   Copyright (C) 2008 Colin Jones
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 **/

#include "cwallpaper-fltk.h"


void loadAndSetLast(CWallpaperSettings *settings)
{
	printf("Loading last wallpaper.\n");
	FILE *file;
	std::string dataName;
	dataName=  getenv("HOME");	
	dataName += "/.config/cwallpaper/lastwallpaper";
	file = fopen(dataName.c_str(), "r");
	if (file == NULL)
		{
			printf("Last wallpaper not found. (You have not used CWallpaper before)\n");
			return;
		}
		if (file != NULL)
		{
			char c;
			std::string string;
			bool getType = true;

			bool scanning = true;
			while (scanning)
			{
				c = fgetc(file);			
				if (c == EOF)
				{
					scanning = false;					
				}
				if (c == 10 || c== 58 || c == EOF)
				{
					
					if (getType)
					{
						if (string.compare("c") == 0)
						{
							settings->setCurrentOption(1);
			
						}
						if (string.compare("s") == 0)
						{
							settings->setCurrentOption(0);
			
						}
						if (string.compare("t") == 0)
						{
							settings->setCurrentOption(2);
			
						}
						if (string.compare("n") == 0)
						{
							settings->setCurrentOption(3);
							settings->setOptions(false);
						}						
						getType = false;
					}
					else
					{					
						settings->setDirectory("");
						settings->setImageName(string.c_str());
					}
					
					string = "";
				}
				
				else
				{
					string += c;
				}
			}
			fclose(file);
			
		}
		settings->setWallpaper();
	
}

void saveLast(CWallpaperSettings *settings)
{
	if (settings->hasChanged())
	{	
		FILE *file;
		std::string dataName;
		std::string lastWallpaperString = "";
		dataName = getenv("HOME");	
		dataName += "/.config/cwallpaper/lastwallpaper";
		file = fopen(dataName.c_str(), "w");
	
		if (settings->hasOptions() == false)
		{
			lastWallpaperString = "n:";
		}
		else 
		{	
			if (settings->getCurrentOption() == 0)
			{
				lastWallpaperString = "s:";
			}
			if (settings->getCurrentOption() == 1)
			{
				lastWallpaperString = "c:";
			}
			if (settings->getCurrentOption() == 2)
			{
				lastWallpaperString = "t:";
			}
		}	
		
		lastWallpaperString += settings->getFilename();
		fputs(lastWallpaperString.c_str(), file);
		fclose(file);
	}
	
	
}

void loadSettings(std::string configFile, CWallpaperSettings *settings)
{
		/** 
		* Set the default options, in case the user doesn't have a config.
		**/
		settings->setProgram((char *)"fbsetbg", (char *)"-a", (char *)"-t", (char *)"-c");		
		settings->setCurrentOption(0);
		settings->setOptions(true);
	
		/**
		* Options: 0 = scale, 1 = center, 2 = tile, 3 = none
		**/
		FILE *file;		
		file = fopen(configFile.c_str(), "r");
		printf("Loading settings from: %s....\n", configFile.c_str());
		if (file == NULL)
		{
			printf("Config file: %s doesn't exist.\n", configFile.c_str());
			return;
		}
		if (file != NULL)
		{
			char c;
			std::string string;
			bool getProgram = false;
			bool getScale = false;
			bool getCenter = false;
			bool getDefault = false;
			bool getTile = false;
			bool scanning = true;
			while (scanning)
			{
				c = fgetc(file);			
				if (c == EOF)
				{
					scanning = false;					
				}
				if (c == 10 || c == 32 || c == EOF)
				{
					if (getProgram)
					{
			
						settings->setProgram(string.c_str());
						getProgram = false;
					}
					if (getScale)
					{
			
						settings->setScaleOption(string.c_str());
						getScale = false;
					}
					if (getDefault)
					{
						if (string.compare("c") == 0)
						{
							settings->setCurrentOption(1);
			
						}
						if (string.compare("s") == 0)
						{
							settings->setCurrentOption(0);
			
						}
						if (string.compare("t") == 0)
						{
							settings->setCurrentOption(2);
			
						}
						if (string.compare("n") == 0)
						{
							settings->setCurrentOption(3);
							settings->setOptions(false);
						}						
						getDefault = false;
					}
					if (getCenter)
					{
			
						settings->setCenterOption(string.c_str());
						getCenter = false;
					}
					if (getTile)
					{

						settings->setTileOption(string.c_str());
						getTile = false;
					}
				 	
						if (string.compare("program:") == 0)
						{
							getProgram = true;
						}
						if (string.compare("scale:") == 0)
						{
							getScale = true;
						}
						if (string.compare("tile:") == 0)
						{
							getTile = true;
						}
						if (string.compare("center:") == 0)
						{
							getCenter = true;
						}
						if (string.compare("default:") == 0)
						{
							getDefault = true;
						}
					string = "";
				}
				
				else
				{
					string += c;
				}
			}
			fclose(file);
		}
		printf("Done.\n");
}


void select_image(Fl_Widget *wallpaper_list, void*inGui) 
{
	CWallpaperGUI *gui = (CWallpaperGUI*)inGui;
	CWallpaperSettings *settings = gui->get_settings();
	
	for (int x = 0; x < ((Fl_Browser*)wallpaper_list)->size() + 1; x ++)
	{
		if (((Fl_Browser*)wallpaper_list)->selected(x))
		{
			settings->setImageName(((Fl_Browser*)wallpaper_list)->text(x));
			gui->previewImage();
		}
	}
}

void set_option(Fl_Widget *optionsCombo, void*inGui) 
{
	CWallpaperGUI *gui = (CWallpaperGUI*)inGui;
	CWallpaperSettings *settings = gui->get_settings();
	
	int selectedOption = ((Fl_Menu_*)optionsCombo)->value();
	
	settings->setCurrentOption(selectedOption);
	
	optionsCombo->copy_label(((Fl_Menu_*)optionsCombo)->text());
}
void set_dir(Fl_Widget *dirCombo, void*inGui) 
{
	CWallpaperGUI *gui = (CWallpaperGUI*)inGui;
	CWallpaperSettings *settings = gui->get_settings();
	
	settings->setDirectory(((Fl_Menu_*)dirCombo)->text());
	
	gui->set_wallpaper_list(settings->getDirectory().c_str());
	
	dirCombo->copy_label(((Fl_Menu_*)dirCombo)->text());
  
}
void apply_wallpaper(Fl_Widget *, void*inGui) 
{
	CWallpaperGUI *gui = (CWallpaperGUI*)inGui;
	CWallpaperSettings *settings = gui->get_settings();
	
	settings->setWallpaper();
	
  
}
void build_folder_list(Fl_Menu_Button *dirCombo)
{
	std::string dataName;
	dataName = getenv("HOME");	
		dataName += "/.config/cwallpaper/wallpaper_folders";
	char c;
	char string[1024];
	int i = 0;
	
	FILE *file = fopen(dataName.c_str(), "r");

	if (!file) {return;}
	
	do {
		c = getc(file);
		if (c == '\n' || c <= 0 || i >=1024-1)
		{
			string[i] = 0;
			dirCombo->add(string);
			i = 0;
		}
		else
		{
			string[i ++] = c;
		}
	} while (c >= 0);
	fclose(file);
	return;
}

void exit_CWallpaper(Fl_Widget*, void*inSettings) 
{
	CWallpaperSettings *settings = (CWallpaperSettings*)inSettings;
	saveLast(settings);
	exit(0);
}




int main(int argc, char *argv[])
{
	
	CWallpaperSettings *settings= new CWallpaperSettings();
	std::string dataName;
	dataName = getenv("HOME");	
	dataName += "/.config/cwallpaper/config";
	int configIndex = 0;
	bool lastWallpaper = false;
	if (argc < 2)
	{
		loadSettings(dataName.c_str(), settings);	
	}
	else //Open the file which is arg 1 
	{
		int x;
		for (x =0; x < argc; x++)
		{
			//Check for additional options.
			if (strcmp(argv[x], "-l") == 0)
			{
				lastWallpaper = true;
				
			}
			if (strcmp(argv[x], "-c") == 0)
			{
				configIndex = x + 1;
				
			}
		}
		if (configIndex > 0)
		{
			loadSettings(argv[configIndex], settings);
		}
		else
		{
			loadSettings(dataName.c_str(), settings);
		}
		if (lastWallpaper)
		{
			loadAndSetLast(settings);
			return 0;
		}
	}
	
	Fl::scheme(); 
	
	Fl::visual(FL_RGB);
	
	CWallpaperGUI cwallpaper_gui;
	
	cwallpaper_gui.set_settings(settings);
	cwallpaper_gui.make_gui(argc, argv);
	
	return Fl::run();

}

