#include "cwallpaper-common.h"
#include "cwallpaper-gui.h"
#include "cwallpaper-settings.h"
#include "cwallpaper-menu.h"

CWallpaperGUI::CWallpaperGUI()
{
	image = NULL;
}
CWallpaperGUI::~CWallpaperGUI()
{
	
}

int CWallpaperGUI::make_gui(int argc, char *argv[])
{
	
	fl_register_images();
	
	
	
	Fl_Window *main_window = new Fl_Window(475, 310, "CWallpaper");
	main_window->begin();
	
	box = box = new Fl_Box (4, 4, PREVIEW_SIZE, PREVIEW_SIZE);
	box->align (FL_ALIGN_CENTER);
	box->align (FL_ALIGN_CLIP);
	box->box (FL_FLAT_BOX);
	box->labelfont (0);
	box->labelsize (9);
	box->when (FL_WHEN_NEVER);

	Fl_Group *settingsBox = new Fl_Group(4, 265, 256, 40, "Wallpaper Settings");
	settingsBox->box(FL_THIN_DOWN_FRAME);
	settingsBox->labelsize(9);
	settingsBox->labelfont(FL_HELVETICA_ITALIC);
	settingsBox->align(FL_ALIGN_TOP_LEFT|FL_ALIGN_INSIDE);
	
	Fl_Menu_Button* optionsCombo = new Fl_Menu_Button(10, 280, 245, 20);

	optionsCombo->labelfont(0);
	optionsCombo->labelsize(9);
	optionsCombo->align(FL_ALIGN_LEFT|FL_ALIGN_INSIDE);
	optionsCombo->menu(menu_Wallpaper);
	optionsCombo->callback(set_option, (void*)this);
	if (!settings->hasOptions())
	{
		optionsCombo->deactivate();
		
	}
	if (settings->getCurrentOption() == 0)
	{
		optionsCombo->copy_label("&Scale to Fit");
	}
	if (settings->getCurrentOption() == 1)
	{
		optionsCombo->copy_label("&Center");
	}
	if (settings->getCurrentOption() == 2)
	{
		optionsCombo->copy_label("&Tile");
	}
	settingsBox->end();
	Fl_Menu_Button* dirCombo = new Fl_Menu_Button(265, 5, 205, 20);
	dirCombo->labelfont(0);
	dirCombo->labelsize(8);
	dirCombo->textsize(8);
	dirCombo->copy_label("Directories");
	dirCombo->align(FL_ALIGN_LEFT|FL_ALIGN_INSIDE|FL_ALIGN_CLIP);
	build_folder_list(dirCombo);
	dirCombo->callback(set_dir, (void*)this);
	settings->setDirectory("");
	wallpaper_list = new Fl_File_Browser(265, 30, 205, 250);
		wallpaper_list->type(2);
		wallpaper_list->labelfont(0);
		wallpaper_list->labelsize(9);
	
		wallpaper_list->textsize(9);

		wallpaper_list->when(3);
	wallpaper_list->callback(select_image, (void*)this);
	
	

	
	Fl_Return_Button* applyButton = new Fl_Return_Button(370, 285, 100, 20, "&Apply");

      applyButton->labelfont(0);
      applyButton->labelsize(9);

	applyButton->callback(apply_wallpaper, (void*)this);
	main_window->end();
	main_window->callback(exit_CWallpaper, (void*)settings);
	main_window->show(argc, argv);
}

void
CWallpaperGUI::clean_list()
{
	int size = wallpaper_list->size();
	for (int n = 1; n < size; n ++)
	{
		if (strchr(wallpaper_list->text(n), '/') != 0) 
		{ 
			//std::cout << n << " = " << wallpaper_list->text(n) << "\n";
			wallpaper_list->remove(n);
			n --;
			size --;
		}
		
	}
	
	
}

void
CWallpaperGUI::resizeImage ()
{




}
CWallpaperSettings *CWallpaperGUI::get_settings()
{
	return settings;
}

void CWallpaperGUI::set_settings(CWallpaperSettings *settings)
{
	this->settings = settings;
}

void CWallpaperGUI::set_wallpaper_list(const char *directory)
{

	if (wallpaper_list == NULL)
	{
		printf("Error: You tried to load a null wallpaper list.\n");
		return;
	}
	wallpaper_list->clear();
	//printf("Loading %s", directory);
	wallpaper_list->load(directory);
	//printf("Done!\n");
	clean_list();
}

void
CWallpaperGUI::previewImage ()
{
	std::string filename;
	filename = settings->getDirectory();
	filename += "/";
	filename += settings->getImageName();
	//printf("Loading \"%s\"\n", filename);
	
	if (image)
	{
		image->release ();
		image = 0L;
	}
	image = Fl_Shared_Image::get (filename.c_str());

	if (!image)
	{	
		printf("Error: \"%s\" is not an image!\n", filename.c_str());
		box->image (0);
		box->redraw ();
	}	
	else
	{
		//Resize the image before rendering it.
		Fl_Image *temp;
		int width, height;
		int current_w = image->w();
		int current_h = image->h();
		if (current_w * PREVIEW_SIZE > current_h * PREVIEW_SIZE)
		{
			width = PREVIEW_SIZE;
			height = width * current_h / current_w;
		}
		else
		{
			height = PREVIEW_SIZE;
			width = height * current_w / current_h;
		
		}	
	
		temp = image->copy (width, height);
		image->release ();

		image = (Fl_Shared_Image *) temp;
		//Render the image as the box's background.
		box->image (image);
		//Redraw the box.
		box->redraw ();
	}	
}

	
