/**
 *   CWallpaper-fltk - A frontend for root window pixmap changing programs.
 *   Copyright (C) 2008 Colin Jones
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 **/


#include "cwallpaper-settings.h"

CWallpaperSettings::CWallpaperSettings ()
{
  directory ="";
  image_name ="";
  wallpaperListName ="";
  program ="";
  scaleOption ="";
  tileOption ="";
  centerOption ="";
  options = true;
  verbose = false;
  changed = false;
  currentOption = 0;
}

void
CWallpaperSettings::setProgram (const char *program, const char *scaleOption,
				const char *tileOption, const char *centerOption)
{
  this->program = program;
  this->scaleOption = scaleOption;
	this->tileOption = tileOption;
	this->centerOption = centerOption;
  if (verbose)
    {
      printf("Program = \"%s\"\n", this->program.c_str());
      printf("Scale = \"%s\"\n",this->scaleOption.c_str());
      printf("Tile = \"%s\"\n", this->tileOption.c_str());
      printf("Center = \"%s\"\n",this->centerOption.c_str());
      //std::cout << "Program = \"" << program << "\"\n";
    }
}

void
CWallpaperSettings::setProgram (const char *program)
{
  this->program = program;
	if (verbose)
    {
      printf("Program = \"%s\"\n", this->program.c_str());
    }
}

void
CWallpaperSettings::setScaleOption (const char *option)
{
   this->scaleOption = option;
	if (verbose)
    {
      printf("Scale = \"%s\"\n",this->scaleOption.c_str());
    }
}

void
CWallpaperSettings::setTileOption (const char *option)
{
  this->tileOption = option;
	if (verbose)
    {
      printf("Tile = \"%s\"\n", this->tileOption.c_str());
    }
}

void
CWallpaperSettings::setCenterOption (const char *option)
{
  this->centerOption = option;
	if (verbose)
    {
      printf("Center = \"%s\"\n",this->centerOption.c_str());
    }
}



void
CWallpaperSettings::setDirectory (const char *directory)
{
	
  this->directory= directory;
  

}

std::string  CWallpaperSettings::getDirectory ()
{
  return directory;
}

void
CWallpaperSettings::setImageName (const char *image_name)
{
	
  this->image_name = image_name;
}

std::string
CWallpaperSettings::getImageName ()
{
  return image_name;
}

void
CWallpaperSettings::setFilename(const char *filename)
{
	
  this->filename = filename;
}

std::string CWallpaperSettings::getFilename()
{
	if (filename.empty())
	{
		filename = directory;
		filename +="/";
		filename += image_name;
	}
	return filename;
}
void
CWallpaperSettings::setWallpaperListName (const char *filename)
{
  this->wallpaperListName= filename;
}

std::string 
CWallpaperSettings::getWallpaperListName ()
{
  return wallpaperListName;
}

int
CWallpaperSettings::getCurrentOption ()
{
  return currentOption;
}

void
CWallpaperSettings::setCurrentOption (int currentOption)
{
  this->currentOption = currentOption;
}

bool CWallpaperSettings::hasOptions ()
{
  return options;
}

bool CWallpaperSettings::hasChanged ()
{
  return changed;
}

void
CWallpaperSettings::setOptions (bool options)
{
  this->options = options;
}

void
CWallpaperSettings::setWallpaper ()
{
  std::string command;

  command = "";
	command += program;
	command += " ";
  switch (currentOption)
    {
    case 0:
	    command += scaleOption;
      break;
    case 1:
      command += centerOption;
      break;
    case 2:
      command += tileOption;
      break;
    case 3:

      break;
    }
  command += " ";
  if (!image_name.empty())
    {
	    command += "\"";
	    if (!directory.empty())
	    {
		command += directory;
		command += "/";	
	    }		    
	    command += image_name;
	    command += "\"";
	    printf("Exec: %s\n", command.c_str());
      system (command.c_str());
      changed = true;
    }

}