/**
 *   CWallpaper-fltk - A frontend for root window pixmap changing programs.
 *   Copyright (C) 2008 Colin Jones
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 **/
 
 #include "cwallpaper-common.h"
 
 #ifndef CWALLPAPER_SETTINGS_H
 #define CWALLPAPER_SETTINGS_H
 

class CWallpaperSettings
{
	private:
		std::string filename;
		std::string directory;
		std::string image_name;
		std::string wallpaperListName;
		std::string program;
		std::string scaleOption;
		std::string tileOption;
		std::string centerOption;
		bool options;
		bool verbose;
		bool changed;
		int currentOption;
		
	
	public:
		CWallpaperSettings();
		void setProgram(const char *program, const char* scaleOption, const char*tileOption, const char *centerOption);
	
		void setProgram(const char *program);
	
		void setScaleOption(const char *option);
	
		void setTileOption(const char *option);
	
		void setCenterOption(const char *option);
		
		void setDirectory(const char *directory);
		void setImageName(const char *image_name);
		void setFilename(const char *filename);
		std::string getImageName();
		std::string getDirectory();
		std::string getFilename();
	
		void setWallpaperListName(const char *filename);
	
		std::string getWallpaperListName();
	
		int getCurrentOption();
	
		void setCurrentOption(int currentOption);
	
		bool hasOptions();
		bool hasChanged();
	
		void setOptions(bool options);
	
		void setWallpaper();
		
		void resizeImage();
		
		void previewImage();
	
	
};
#endif